@@ -163,18 +163,6 @@ class AbstractScraper:
             except BaseException:
                 pass
 
-    def get(
-            self,
-            url=None,
-            keywords=None,
-            operator="OR",
-            pages=2,
-            in_data="author"):
-        self._open(
-            url=url, keywords=keywords, operator=operator, pages=pages,
-            in_data=in_data
-        )
-
     async def get_abstracts(
         self, url=None, keywords=None, operator="OR", pages=2, in_data="author"
     ):
@@ -190,7 +178,8 @@ class AbstractScraper:
         :param in_data: "author" or "all_meta" whether to search in author
                 keywords or all metadata
         :type in_data: string
-        :return: pd.DataFrame
+        :return: DataFrame with the scraped abstracs in column="text"
+        :rtype: pd.DataFrame
         """
         await self._open(
             url=url, keywords=keywords, operator=operator, pages=pages,
